pub struct SourceDiagnostic {
pub severity: Severity,
pub span: DiagSpan,
pub message: EcoString,
pub trace: EcoVec<Spanned<Tracepoint>>,
pub hints: EcoVec<Spanned<EcoString, DiagSpan>>,
}Expand description
An error or warning in a source or text file. The recommended way to create
one is with the error! or warning! macros.
The contained spans will only be detached if any of the input source files were detached.
Fields
severity: SeverityWhether the diagnostic is an error or a warning.
span: DiagSpanThe span of a relevant node in a Typst source file or the relevant byte range of an external file.
message: EcoStringA diagnostic message describing the problem.
trace: EcoVec<Spanned<Tracepoint>>The trace of function calls leading to the problem.
hints: EcoVec<Spanned<EcoString, DiagSpan>>Additional hints to the user.
-
When the span is
None, these are generic hints. The CLI renders them as a list at the bottom, each prefixed withhint:. -
When a span is given, the hint is related to a secondary piece of code and will be annotated at that code.
Implementations
Sourceimpl SourceDiagnostic
impl SourceDiagnostic
Sourcepub fn error(
span: impl Into<DiagSpan>,
message: impl Into<EcoString>,
) -> SourceDiagnostic
pub fn error( span: impl Into<DiagSpan>, message: impl Into<EcoString>, ) -> SourceDiagnostic
Create a new, bare error.
Sourcepub fn warning(
span: impl Into<DiagSpan>,
message: impl Into<EcoString>,
) -> SourceDiagnostic
pub fn warning( span: impl Into<DiagSpan>, message: impl Into<EcoString>, ) -> SourceDiagnostic
Create a new, bare warning.
Sourcepub fn spanned_hint(
&mut self,
hint: impl Into<EcoString>,
span: impl Into<DiagSpan>,
)
pub fn spanned_hint( &mut self, hint: impl Into<EcoString>, span: impl Into<DiagSpan>, )
Adds a single hint specific to a source code location to the diagnostic.
Sourcepub fn with_hint(self, hint: impl Into<EcoString>) -> SourceDiagnostic
pub fn with_hint(self, hint: impl Into<EcoString>) -> SourceDiagnostic
Adds a single hint to the diagnostic.
Sourcepub fn with_spanned_hint(
self,
hint: impl Into<EcoString>,
span: impl Into<DiagSpan>,
) -> SourceDiagnostic
pub fn with_spanned_hint( self, hint: impl Into<EcoString>, span: impl Into<DiagSpan>, ) -> SourceDiagnostic
Adds a single hint specific to a source code location to the diagnostic.
Sourcepub fn with_hints(
self,
hints: impl IntoIterator<Item = EcoString>,
) -> SourceDiagnostic
pub fn with_hints( self, hints: impl IntoIterator<Item = EcoString>, ) -> SourceDiagnostic
Adds multiple user-facing hints to the diagnostic.
Sourcepub fn with_tracepoint(
self,
tracepoint: Tracepoint,
span: Span,
) -> SourceDiagnostic
pub fn with_tracepoint( self, tracepoint: Tracepoint, span: Span, ) -> SourceDiagnostic
Adds a single tracepoint to the diagnostic.