pub struct Args {
pub span: Span,
pub items: EcoVec<Arg>,
}Expand description
Captured arguments to a function.
Fields
span: SpanThe callsite span for the function. This is not the span of the argument list itself, but of the whole function call.
items: EcoVec<Arg>The positional and named arguments.
Implementations
Sourceimpl Args
impl Args
Sourcepub fn new<T>(span: Span, values: impl IntoIterator<Item = T>) -> Argswhere
T: IntoValue,
pub fn new<T>(span: Span, values: impl IntoIterator<Item = T>) -> Argswhere
T: IntoValue,
Create positional arguments from a span and values.
Sourcepub fn spanned(self, span: Span) -> Args
pub fn spanned(self, span: Span) -> Args
Attach a span to these arguments if they don’t already have one.
Sourcepub fn insert(&mut self, index: usize, span: Span, value: Value)
pub fn insert(&mut self, index: usize, span: Span, value: Value)
Insert a positional argument at a specific index.
Sourcepub fn eat<T>(&mut self) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
pub fn eat<T>(&mut self) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
Consume and cast the first positional argument if there is one.
Sourcepub fn consume(
&mut self,
n: usize,
) -> Result<Vec<Arg>, EcoVec<SourceDiagnostic>>
pub fn consume( &mut self, n: usize, ) -> Result<Vec<Arg>, EcoVec<SourceDiagnostic>>
Consume n positional arguments if possible.
Sourcepub fn expect<T>(&mut self, what: &str) -> Result<T, EcoVec<SourceDiagnostic>>
pub fn expect<T>(&mut self, what: &str) -> Result<T, EcoVec<SourceDiagnostic>>
Consume and cast the first positional argument.
Returns a missing argument: {what} error if no positional argument is
left.
Sourcepub fn find<T>(&mut self) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
pub fn find<T>(&mut self) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
Find and consume the first castable positional argument.
Sourcepub fn all<T>(&mut self) -> Result<Vec<T>, EcoVec<SourceDiagnostic>>
pub fn all<T>(&mut self) -> Result<Vec<T>, EcoVec<SourceDiagnostic>>
Find and consume all castable positional arguments.
Sourcepub fn named<T>(
&mut self,
name: &str,
) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
pub fn named<T>( &mut self, name: &str, ) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
Cast and remove the value for the given named argument, returning an error if the conversion fails.
Sourcepub fn named_or_find<T>(
&mut self,
name: &str,
) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
pub fn named_or_find<T>( &mut self, name: &str, ) -> Result<Option<T>, EcoVec<SourceDiagnostic>>
Same as named, but with fallback to find.
Sourceimpl Args
impl Args
Sourcepub fn at(
&self,
key: ArgumentKey,
default: Option<Value>,
) -> Result<Value, EcoString>
pub fn at( &self, key: ArgumentKey, default: Option<Value>, ) -> Result<Value, EcoString>
Returns the positional argument at the specified index, or the named argument with the specified name.