pub trait SettableProperty<const I: u8>: NativeElement {
type Type: Clone;
const FIELD: SettablePropertyData<Self, I>;
const FOLD: Option<fn(Self::Type, Self::Type) -> Self::Type> = _;
// Provided methods
fn default() -> Self::Type { ... }
fn default_ref() -> &'static Self::Type { ... }
}Expand description
A field that has a default value and can be configured via a set rule, but is never present on elements.
This is provided for all SettableField impls through a blanket impl. In
the case of #[ghost] fields, which only live in the style chain and not in
elements, it is also implemented manually.
Required Associated Constants
const FIELD: SettablePropertyData<Self, I>
Provided Associated Constants
Required Associated Types
Provided Methods
Sourcefn default_ref() -> &'static Self::Type
fn default_ref() -> &'static Self::Type
Produces a static reference to this property’s default value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".