ShowSet

Trait ShowSet 

pub trait ShowSet {
    // Required method
    fn show_set(&self, styles: StyleChain<'_>) -> Styles;
}
Defines built-in show set rules for an element.

This is a bit more powerful than a user-defined show-set because it can access the element’s fields.

Required Methods

fn show_set(&self, styles: StyleChain<'_>) -> Styles

Finalize the fully realized form of the element. Use this for effects that should work even in the face of a user-defined show rule.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors