Diagnostics.
Macros
- eco_
format - Create a new
EcoStringfrom a format string. - eco_vec
- Create a new
EcoVecwith the given elements.
Structs
- EcoString
- An economical string with inline storage and clone-on-write semantics.
- EcoVec
- An economical vector with clone-on-write semantics.
- Hinted
String - A string message with hints. The recommended way to create one is with the
error!macro. - LineCol
- A line/column pair.
- Load
Error - A call site independent error that occurred during data loading. This avoids
polluting the memoization with
Spans andFileIds from source files. Can be turned into aSourceDiagnosticusing theLoadedWithin::withinmethod available onLoadResult. - Source
Diagnostic - An error or warning in a source or text file. The recommended way to create
one is with the
error!orwarning!macros. - Warned
- An output alongside warnings generated while producing it.
Enums
- File
Error - An error that occurred while trying to load a file.
- Package
Error - An error that occurred while trying to load a package.
- Report
Text Pos - A position in a text document at which an error was reported.
- Severity
- The severity of a
SourceDiagnostic. - Tracepoint
- A part of a diagnostic’s trace.
Traits
- At
- Convert a
StrResultorHintedStrResultto aSourceResultby adding span information. - Collect
Combined Result - Collects an iterator of
SourceResults into a result containg a collection or the accumulated errors. - Expect
Internal - Adds a method analogous to
Option::expectthat raises an internal compiler error instead of panicking. - Hint
- Enrich a
StrResultorHintedStrResultwith a hint. - Loaded
Within - Convert a
LoadErroror compatibleResultto aSourceDiagnosticorSourceResultby adding theLoadedcontext. - Parallel
Collect Combined Result - A variation of
CollectCombinedResultfor parallel rayon iterators. - Trace
- Enrich a
SourceResultwith a tracepoint. - Warning
Sink - Destination for a warning message.
Functions
- assert_
internal - Asserts a condition, generating an internal compiler error with the provided message on failure.
- format_
xml_ like_ error - Format a user-facing error message for an XML-like file format.
- panic_
internal - Generates an internal compiler error with the provided message.
Type Aliases
- File
Result - A result type with a file-related error.
- Hinted
StrResult - A result type with a string error message and hints. The recommended way to
create an error for this type is with the
bail!macro. - Load
Result - A result type with a data-loading-related error.
- Package
Result - A result type with a package-related error.
- Source
Result - A result that can carry multiple source errors. The recommended way to
create an error for this type is with the
bail!macro. - StrResult
- A result type with a string error message. The recommended way to create an
error for this type is with the [
bail!] macro.